#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;

namespace Polenter.Mcm
{
    ///<summary>
    /// Result of an async operation. Informs about an error and cancellation if any.
    /// All asynchronous executed operations should post an inheritor of this
    /// message to the message channel
    ///</summary>
    public class AsyncOperationResponseMessage
    {
        ///<summary>
        ///</summary>
        public AsyncOperationResponseMessage()
        {
        }

        ///<summary>
        ///</summary>
        ///<param name="error"></param>
        public AsyncOperationResponseMessage(Exception error)
        {
            Error = error;
        }

        ///<summary>
        ///</summary>
        ///<param name="error"></param>
        ///<param name="cancelled"></param>
        public AsyncOperationResponseMessage(Exception error, bool cancelled)
        {
            Error = error;
            Cancelled = cancelled;
        }

        ///<summary>
        ///</summary>
        public Exception Error { get; private set; }

        ///<summary>
        ///</summary>
        public bool Cancelled { get; private set; }

        ///<summary>
        ///</summary>
        public bool HasError
        {
            get { return Error != null; }
        }
    }
}