#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;

namespace Polenter.Mcm
{
    /// <summary>
    /// Stores information under what key was the component stored in the container
    /// </summary>
    internal class ComponentInfo
    {
        public ComponentInfo(object component)
        {
            if (component == null) throw new ArgumentNullException("component");
            Key = component.GetType();
            Component = component;
        }

        public ComponentInfo(object component, Type key)
        {
            if (key == null) throw new ArgumentNullException("key");
            if (component == null) throw new ArgumentNullException("component");
            Key = key;
            Component = component;
        }

        public Type Key { get; private set; }
        public object Component { get; private set; }

        public override string ToString()
        {
            if (Key != Component.GetType())
            {
                return string.Format("{0}, {1}", Key, Component);
            }
            return Component.ToString();
        }
    }
}