#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;

namespace Polenter.Mcm
{
    /// <summary>
    /// Is executed synchronously. Informs about the last error if any.
    /// </summary>
    public interface IMcmCommand
    {
        ///<summary>
        /// Contains last error of the execution if  any
        ///</summary>
        Exception Error { get; }

        ///<summary>
        /// Informs if the last execution has finished with an error
        ///</summary>
        bool HasError { get; }

        /// <summary>
        /// Executes the command synchronously
        /// </summary>
        /// <returns>false if there is an error occured</returns>
        bool Execute();

        ///<summary>
        /// Invoked always after the execution. 
        /// The property Error contains the last error if any.
        ///</summary>
        event EventHandler ExecuteCompleted;
    }
}