#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;
using System.Collections.ObjectModel;
using System.Runtime.CompilerServices;

namespace Polenter.Mcm
{
    ///<summary>
    ///</summary>
    internal class MessageChannelCollection : KeyedCollection<string, MessageChannel>
    {
        ///<summary>
        ///</summary>
        public MessageChannelCollection()
        {
        }

        protected override string GetKeyForItem(MessageChannel item)
        {
            return item.Name;
        }

        protected override void ClearItems()
        {
            foreach (MessageChannel item in Items)
            {
                item.MessageArrived -= on_item_MessageArrived;
            }
            base.ClearItems();
        }

        protected override void InsertItem(int index, MessageChannel item)
        {
            if (item == null) throw new ArgumentNullException("item");
            item.MessageArrived += on_item_MessageArrived;
            base.InsertItem(index, item);
        }

        private void on_item_MessageArrived(object sender, MessageEventArgs e)
        {
            invokeMessageArrived(e);
        }

        protected override void RemoveItem(int index)
        {
            if (Items.Count > index)
            {
                MessageChannel item = Items[index];
                item.MessageArrived -= on_item_MessageArrived;
            }
            base.RemoveItem(index);
        }

        protected override void SetItem(int index, MessageChannel item)
        {
            if (item == null) throw new ArgumentNullException("item");
            if (Items.Count > index)
            {
                MessageChannel oldItem = Items[index];
                oldItem.MessageArrived -= on_item_MessageArrived;
            }

            item.MessageArrived += on_item_MessageArrived;
        }

        internal event EventHandler<MessageEventArgs> MessageArrived;

        [MethodImpl(MethodImplOptions.Synchronized)]
        private void invokeMessageArrived(MessageEventArgs e)
        {
            EventHandler<MessageEventArgs> handler = MessageArrived;
            if (handler != null) handler(this, e);
        }
    }
}