#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;
using System.Reflection;

namespace Polenter.Mcm
{
    /// <summary>
    /// Contains information about invoking the subscriber method
    /// </summary>
    internal class MessageInvoker
    {
        /// <summary>
        /// For which message type should the method be invoked
        /// </summary>
        public Type MessageType { get; set; }

        /// <summary>
        /// Which method should be invoked
        /// </summary>
        public MethodInfo MethodInfo { get; set; }

        /// <summary>
        /// The host object of the method
        /// </summary>
        public object InvokerObject { get; set; }

        /// <summary>
        /// In which thread should the method be invoked.
        /// </summary>
        public UIThreadSynchronizationMode UiThreadSynchronizationMode { get; set; }

        public override string ToString()
        {
            return string.Format("{0} {1}; MessageType={2}", InvokerObject, MethodInfo, MessageType);
        }
    }
}