#region License
// Product:
// MCM (Message-Command-Message)
// mcm-framework.net
// 
// Author:
// Pawel Idzikowski
// Cologne, Germany
// idzikowski@polenter.com
// 
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the author(s) be held liable for any damages arising from
// the use of this software.
// 
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
// 
//     1. The origin of this software must not be misrepresented; you must not
//       claim that you wrote the original software. If you use this software
//       in a product, an acknowledgment in the product documentation would be
//       appreciated but is not required.
// 
//     2. Altered source versions must be plainly marked as such, and must not
//       be misrepresented as being the original software.
// 
//     3. This notice may not be removed or altered from any source distribution.
// 
#endregion
using System;

namespace Polenter.Mcm
{
    /// <summary>
    /// Possible only for, the method will be attached to the subscriber list of the message channel
    /// </summary>
    [AttributeUsageAttribute(AttributeTargets.Method, Inherited = false, AllowMultiple = false)]
    public sealed class MessageSubscriberAttribute : Attribute
    {
        ///<summary>
        ///</summary>
        ///<param name="messageChannelName">MessageChannel broadcasting the messages</param>
        public MessageSubscriberAttribute(string messageChannelName)
        {
            MessageChannelName = messageChannelName;
        }

        ///<summary>
        ///</summary>
        ///<param name="messageChannelName">MessageChannel broadcasting the messages</param>
        ///<param name="uiThreadSynchronizationMode">Should the method be invoked in the original thead or in the UI thread</param>
        public MessageSubscriberAttribute(string messageChannelName, UIThreadSynchronizationMode uiThreadSynchronizationMode)
        {
            MessageChannelName = messageChannelName;
            UIThreadSynchronizationMode = uiThreadSynchronizationMode;
        }

        ///<summary>
        /// MessageChannel broadcasting the messages
        ///</summary>
        public string MessageChannelName { get; private set; }

        ///<summary>
        /// In which thread the method will be invoked. 
        /// Default is no synchronization, so the method will be invoked
        /// in the internal thread of the message channel.
        ///</summary>
        public UIThreadSynchronizationMode UIThreadSynchronizationMode { get; set; }
    }
}